Jarvis · Admin Dashboard

## Dashboard

Agenten
—
Konfiguriert
Aktive Sessions
—
Auth-Gateway
Skills installiert
—
Marketplace
Heartbeat-Tasks
—
Alle Agenten
System-Metriken (24h)
CPU · RAM · Tokens pro Stunde
Letzte Ereignisse
📭
Noch keine Ereignisse
Schnellzugriff
🧙
Konfig-Assistent
Heartbeat, Agents oder Bindings per Wizard einrichten
🏪
Skill-Marktplatz
Skills durchsuchen, installieren und bewerten
📡
Live-Monitoring
CPU, RAM, Tokens und Events in Echtzeit
CPU
—%
RAM
— MB
Token/h
—
Uptime
—
Metriken-Verlauf
System-Events
Konfigurierte Agenten

Name | Modell | Sandbox | Tools | Status
--- | --- | --- | --- | ---
Lade Agenten...

Per-Agent Heartbeat-Tasks
Tokens
—
Aktive
—
Sessions
—
Benutzer
—
Audit-Log
Skills
—
Verifiziert
—
Kategorien
—
∅ Bewertung
—
Featured Skills
Trending (7 Tage)
Installiert
—
Updates
—
Recalls
—
Strategie
—
Ausstehende Updates

Paket | Aktuell | Verfügbar | Dringlichkeit | Aktion
--- | --- | --- | --- | ---
Keine ausstehenden Updates

Konfiguration
Presets
Konfigurations-Assistenten
Routing-Regeln

Name | Kanal | Agent | Muster | Priorität
--- | --- | --- | --- | ---
Lade Bindings...

Slash-Commands

Command | Beschreibung | Scope | Auth | Cooldown
--- | --- | --- | --- | ---